pub struct TesseraConfig {
pub include_paths: Vec<String>,
pub exclude_paths: Vec<String>,
pub ignore_names: Vec<String>,
}Fields
include_paths: Vec<String>Only index paths with one of these relative path prefixes. Empty means all.
exclude_paths: Vec<String>Skip paths with one of these relative path prefixes.
ignore_names: Vec<String>Extra directory or file names to skip during traversal.
Implementations
Sourceimpl TesseraConfig
impl TesseraConfig
pub fn load(root: &Path) -> Self
pub fn parse_lossy(content: &str) -> Self
pub fn includes_path(&self, rel_path: &str) -> bool
pub fn excludes_path(&self, rel_path: &str) -> bool
pub fn ignores_name(&self, name: &str) -> bool